==> openjpa_2.0.0.orig.tar.gz: openjpa-2.0.0.orig/openjpa-kernel/src/main/java/org/apache/openjpa/kernel/ResultShapePacker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.apache.openjpa.kernel;


/**
 * Packs result by delegation to a ResultShape.
 * 
 * @author Pinaki Poddar
 *
 */
public class ResultShapePacker extends ResultPacker {
    private final ResultShape<?> _shape;
    private final Class<?>[] _types;
    private final String[] _aliases;
    public ResultShapePacker(Class<?>[] types, String[] aliases, Class resultClass, ResultShape<?> shape) {
        super(); // bypass superclass implementation
        _shape = shape;
        _types = types;
        _aliases = aliases;
    }
    
    @Override
    public Object pack(Object o) {
        return pack(new Object[]{o});
    }
    
    @Override
    public Object pack(Object[] values) {
        if (_shape == null)
            return super.pack(values);
        return _shape.pack(values, _types, _aliases);
    }

}

==> openjpa_2.2.2.orig.tar.gz: openjpa-2.2.2.orig/openjpa-kernel/src/main/java/org/apache/openjpa/kernel/ResultShapePacker.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.apache.openjpa.kernel;

import java.util.Calendar;

import org.apache.openjpa.util.ProxyCalendar;


/**
 * Packs result by delegation to a ResultShape.
 * 
 * @author Pinaki Poddar
 *
 */
public class ResultShapePacker extends ResultPacker {
    private final ResultShape<?> _shape;
    private final Class<?>[] _types;
    private final String[] _aliases;
    public ResultShapePacker(Class<?>[] types, String[] aliases, Class resultClass, ResultShape<?> shape) {
        super(); // bypass superclass implementation
        _shape = shape;
        _types = types;
        _aliases = aliases;
    }
    
    @Override
    public Object pack(Object o) {
        return pack(new Object[]{o});
    }
    
    @Override
    public Object pack(Object[] values) {
        // Check for proxied calenders and cleanup if any are found.
        if (_types != null) {
            for (Class<?> t : _types) {
                if (t.equals(Calendar.class)) {
                    for (int i = 0; i < values.length; i++) {
                        if (values[i] instanceof ProxyCalendar) {
                            values[i] = ((ProxyCalendar) values[i]).copy((ProxyCalendar) values[i]);
                        }
                    }
                }
            }
        }
        if (_shape == null)
            return super.pack(values);
        return _shape.pack(values, _types, _aliases);
    }

}
